@@ -351,7 +351,7 @@ data Match =
 
 data Condition =
     HasVariable Variable
-  | HasType Text
+  | HasType [Text]
   | IsUncertainDate Variable
   | IsNumeric Variable
   | HasLocatorType Variable
@@ -683,7 +683,8 @@ data SecondFieldAlign =
     deriving (Show, Eq)
 
 data PageRangeFormat =
-    PageRangeChicago
+    PageRangeChicago15
+  | PageRangeChicago16
   | PageRangeExpanded
   | PageRangeMinimal
   | PageRangeMinimalTwo
@@ -1081,8 +1082,9 @@ data Val a =
     TextVal Text      -- ^ Plain text value
   | FancyVal a        -- ^ Formatted value with parameterized type
   | NumVal  Int       -- ^ Numerical value
-  | NamesVal [Name]    -- ^ Structured names
-  | DateVal Date       -- ^ Structured date
+  | NamesVal [Name]   -- ^ Structured names
+  | DateVal Date      -- ^ Structured date
+  | SubstitutedVal    -- ^ Value suppressed through substitution
   deriving (Show, Ord, Eq, Functor, Foldable, Traversable)
 
 instance ToJSON a => ToJSON (Val a) where
@@ -1091,6 +1093,7 @@ instance ToJSON a => ToJSON (Val a) where
   toJSON (NumVal n) = toJSON n
   toJSON (NamesVal ns) = toJSON ns
   toJSON (DateVal d) = toJSON d
+  toJSON SubstitutedVal = toJSON ()
 
 valToText :: CiteprocOutput a => Val a -> Maybe Text
 valToText (TextVal x)  = Just x
@@ -1480,7 +1483,7 @@ data Identifier =
 identifierToURL :: Identifier -> Text
 identifierToURL ident =
     case ident of
-      IdentDOI t   -> tolink "https://doi.org/" (fixShortDOI t)
+      IdentDOI t   -> tolink "https://doi.org/" t
       IdentPMCID t -> tolink "https://www.ncbi.nlm.nih.gov/pmc/articles/" t
       IdentPMID t  -> tolink "https://www.ncbi.nlm.nih.gov/pubmed/" t
       IdentURL t   -> tolink "https://" t
@@ -1489,6 +1492,8 @@ identifierToURL ident =
                            then x
                            else pref <> x
 
+{-# DEPRECATED fixShortDOI
+   "This function is no longer used and will be removed." #-}
 -- see https://shortdoi.org
 fixShortDOI :: Text -> Text
 fixShortDOI x = if "10/" `T.isPrefixOf` x
@@ -1636,7 +1641,13 @@ formatted formatting = grouped' . filter (not . isNullOutput)
 
 readAsInt :: Text -> Maybe Int
 readAsInt t =
-  case TR.decimal t of
+  case T.uncons t of
+    Just ('-', t') -> (0 -) <$> readAsDecimal t'
+    Just (c, _) | isDigit c -> readAsDecimal t
+    _ -> Nothing
+  where
+    readAsDecimal s =
+      case TR.decimal s of
       Right (x,t') | T.null t' -> Just x
       _                        -> Nothing
 
